@@ -1,29 +1,28 @@
-context("SystemMetadata")
 test_that("datapack library loads", {
 	expect_true(library(datapack, logical.return = TRUE))
 })
 test_that("SystemMetadata constructors", {
     library(datapack)
     sysmeta <- new("SystemMetadata")
-    expect_that(sysmeta@serialVersion, equals(1))
+    expect_equal(sysmeta@serialVersion, 1)
     expect_true(is.na(sysmeta@identifier))
     sysmeta <- new("SystemMetadata", identifier="TestId", formatId="text/csv")
-    expect_that(sysmeta@identifier, equals("TestId"))
-    expect_that(sysmeta@formatId, equals("text/csv"))
+    expect_equal(sysmeta@identifier, "TestId")
+    expect_equal(sysmeta@formatId, "text/csv")
 })
 test_that("XML SystemMetadata parsing works", {
   library(datapack)
   library(XML)
   testid <- "doi:10.xxyy/AA/tesdoc123456789"
   sysmeta <- new("SystemMetadata")
-  expect_that(sysmeta@serialVersion, equals(1))
+  expect_equal(sysmeta@serialVersion, 1)
   doc <- xmlParseDoc("../testfiles/sysmeta.xml", asText=FALSE)
   expect_match(xmlValue(xmlRoot(doc)[["identifier"]]), testid)
   xml <- xmlRoot(doc)
   #getEncoding(doc)
   sysmeta <- parseSystemMetadata(sysmeta, xmlRoot(xml))
   expect_match(sysmeta@identifier, testid)
-  expect_that(nrow(sysmeta@accessPolicy), equals(5))
+  expect_equal(nrow(sysmeta@accessPolicy), 5)
   expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
   expect_true(sysmeta@archived)
   csattrs <- xmlAttrs(xml[["checksum"]])
@@ -39,13 +38,13 @@ test_that("XML SystemMetadata parsing works", {
   # Parse v2.0 system metadata
   testid <- "0007f892-0d8f-4451-94e9-94d02ba5dd0d_0"
   sysmeta <- new("SystemMetadata")
-  expect_that(sysmeta@serialVersion, equals(1))
+  expect_equal(sysmeta@serialVersion, 1)
   doc <- xmlParseDoc("../testfiles/sysmeta-v2.xml", asText=FALSE)
   expect_match(xmlValue(xmlRoot(doc)[["identifier"]]), testid)
   xml <- xmlRoot(doc)
   sysmeta <- parseSystemMetadata(sysmeta, xmlRoot(xml))
   expect_match(sysmeta@identifier, testid)
-  expect_that(nrow(sysmeta@accessPolicy), equals(1))
+  expect_equal(nrow(sysmeta@accessPolicy), 1)
   expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
   expect_false(sysmeta@archived)
   csattrs <- xmlAttrs(xml[["checksum"]])
@@ -57,7 +56,7 @@ test_that("XML SystemMetadata parsing works", {
   # Parse v2.0 system metadata, checking parsing of replication policy
   testid <- "0007f892-0d8f-4451-94e9-94d02ba5dd0d_0"
   sysmeta <- new("SystemMetadata")
-  expect_that(sysmeta@serialVersion, equals(1))
+  expect_equal(sysmeta@serialVersion, 1)
   doc <- xmlParseDoc("../testfiles/sysmeta-v2-repfalse.xml", asText=FALSE)
   expect_match(xmlValue(xmlRoot(doc)[["identifier"]]), testid)
   xml <- xmlRoot(doc)
@@ -67,7 +66,7 @@ test_that("XML SystemMetadata parsing works", {
   # Parse v2.0 system metadata, checking parsing when missing numReplicas
   testid <- "arctic-data.9794.1"
   sysmeta <- new("SystemMetadata")
-  expect_that(sysmeta@serialVersion, equals(1))
+  expect_equal(sysmeta@serialVersion, 1)
   doc <- xmlParseDoc("../testfiles/sysmeta-v2-repfalse-zero-reps.xml", asText=FALSE)
   expect_match(xmlValue(xmlRoot(doc)[["identifier"]]), testid)
   xml <- xmlRoot(doc)
@@ -80,7 +79,7 @@ test_that("XML SystemMetadata serialization works", {
     library(XML)
     testid <- "doi:10.xxyy/AA/tesdoc123456789"
     sysmeta <- new("SystemMetadata")
-    expect_that(sysmeta@serialVersion, equals(1))
+    expect_equal(sysmeta@serialVersion, 1)
     xml <- xmlParseDoc("../testfiles/sysmeta.xml", asText=FALSE)
     expect_match(xmlValue(xmlRoot(xml)[["identifier"]]), testid)
     sysmeta <- parseSystemMetadata(sysmeta, xmlRoot(xml))
@@ -124,7 +123,7 @@ test_that("SystemMetadata XML constructor works", {
     xml <- xmlRoot(doc)
     sysmeta <- SystemMetadata(xmlRoot(xml))
     expect_match(sysmeta@identifier, testid)
-    expect_that(nrow(sysmeta@accessPolicy), equals(5))
+    expect_equal(nrow(sysmeta@accessPolicy), 5)
     expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
     expect_true(sysmeta@archived)
     csattrs <- xmlAttrs(xml[["checksum"]])
@@ -142,22 +141,22 @@ test_that("SystemMetadata validation works", {
     expect_true(isValid)
     sysmeta <- new("SystemMetadata", identifier="foo", checksum="jdhdjhfd", rightsHolder="ff")
     errors <- validate(sysmeta)
-    expect_that(length(errors), equals(2))
+    expect_equal(length(errors), 2)
 })
 
 test_that("SystemMetadata accessPolicy can be constructed and changed", {
     apolicy=data.frame(list("public", "read"))
     colnames(apolicy) <- c("subject", "permission")
     sysmeta <- new("SystemMetadata", identifier="foo", formatId="text/csv", size=59, checksum="jdhdjhfd", rightsHolder="ff", accessPolicy=apolicy)
-    expect_that(sysmeta@serialVersion, equals(1))
-    expect_that(nrow(sysmeta@accessPolicy), equals(1))
+    expect_equal(sysmeta@serialVersion, 1)
+    expect_equal(nrow(sysmeta@accessPolicy), 1)
     expect_match(as.character(sysmeta@accessPolicy$permission[[1]]), "read")
     
     sysmeta <- addAccessRule(sysmeta, "foo", "write")
-    expect_that(nrow(sysmeta@accessPolicy), equals(2))
+    expect_equal(nrow(sysmeta@accessPolicy), 2)
     # Try to add same rule again and make sure it didn't get duplicated
     sysmeta <- addAccessRule(sysmeta, "foo", "write")
-    expect_that(nrow(sysmeta@accessPolicy), equals(2))
+    expect_equal(nrow(sysmeta@accessPolicy), 2)
     expect_match(as.character(sysmeta@accessPolicy$permission[[2]]), "write")
     expect_true(hasAccessRule(sysmeta, "foo", "write"))
     apolicy=data.frame(subject=c("bar", "baz"), permission= c("changePermission", "write"))
@@ -167,7 +166,7 @@ test_that("SystemMetadata accessPolicy can be constructed and changed", {
     expect_true(hasAccessRule(sysmeta, "bar", "changePermission"))
     expect_true(hasAccessRule(sysmeta, "baz", "write"))
     expect_true(!hasAccessRule(sysmeta, "baz", "changePermission"))
-    expect_that(nrow(sysmeta@accessPolicy), equals(4))
+    expect_equal(nrow(sysmeta@accessPolicy), 4)
     expect_match(as.character(sysmeta@accessPolicy$permission[[4]]), "write")
     expect_match(as.character(sysmeta@accessPolicy$subject[[4]]), "baz")    
 })
